@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.5 (default, Sep  4 2020, 07:30:14)  [GCC 7.3.0]
+# Python 3.8.8 (default, Feb 24 2021, 21:46:12)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -792,7 +792,10 @@ def find_attr_value_(attr_name, node):
         value = attrs.get(attr_name)
     elif len(attr_parts) == 2:
         prefix, name = attr_parts
-        namespace = node.nsmap.get(prefix)
+        if prefix == 'xml':
+            namespace = 'http://www.w3.org/XML/1998/namespace'
+        else:
+            namespace = node.nsmap.get(prefix)
         if namespace is not None:
             value = attrs.get('{%s}%s' % (namespace, name, ))
     return value
